if (typeof localStorage.notifications === 'undefined' || localStorage.notifications === null || localStorage.notifications == "true" || localStorage.notifications == "false") {
	localStorage.notifications = "1";
}

if (typeof localStorage.volume === 'undefined' || localStorage.volume === null) {
	localStorage.volume = 0.3;
}

if (typeof localStorage.lastOnline === 'undefined' || localStorage.lastOnline === null) {
	localStorage.lastOnline = 0;
}

if (typeof localStorage.youtube === 'undefined' || localStorage.youtube === null) {
	localStorage.youtube = "1";
}

if (typeof localStorage.lastVideo === 'undefined' || localStorage.lastVideo === null) {
	localStorage.lastVideo = new Date().getTime();
}

if (typeof localStorage.lastVideoID === 'undefined' || localStorage.lastVideoID === null) {
	localStorage.lastVideoID = "";
}

$.browser.chrome = /chrom(e|ium)/.test(navigator.userAgent.toLowerCase());

var audio = new Audio("sounds/notif.ogg");

function createBasicNotification(id, title, message, iconUrl, buttons) {
	if ($.browser.chrome && !$.browser.opera) {
		chrome.notifications.create(id, {
			type: "basic",
			title: title,
			message: message,
			iconUrl: iconUrl,
			buttons: buttons
		});			
	} else {
		chrome.notifications.create(id, {
			type: "basic",
			title: title,
			message: message,
			iconUrl: iconUrl
		});	
	}

	audio.volume = parseFloat(localStorage.volume) / 3.0;
	audio.play();
}

function createImageNotification(id, title, message, imageUrl, iconUrl, contextMessage, buttons) {
	if ($.browser.chrome && !$.browser.opera) {
		chrome.notifications.create(id, {
			type: "image",
			title: title,
			message: message,
			imageUrl: imageUrl,
			iconUrl: iconUrl,
			contextMessage: contextMessage,
			buttons: buttons
		});			
	} else {
		chrome.notifications.create(id, {
			type: "basic",
			title: title,
			message: message,
			iconUrl: iconUrl,
			contextMessage: contextMessage
		});
	}

	audio.volume = parseFloat(localStorage.volume) / 3.0;
	audio.play();
}

var streamer = [];

$.getJSON('../config.json', function(json) {
	$.each(json, function(key, value) {
		streamer[key] = value;
	});
});

streamer.title = "Hors-Ligne";
streamer.game = "-";
streamer.viewers = "-";

var isLive = false;
var prevStatus = false;
var pauseCheck = 0;

function checkLive() {
	"use strict";
	
	if (pauseCheck > 0) {
		pauseCheck--;
		return;
	}

	$.ajax({
		type: "GET",
		dataType: "json",
		timeout: 20000,
		cache: false,
		url: "https://api.twitch.tv/kraken/streams?channel=" + streamer.twitch_name,
		headers: {
			"Client-ID": streamer.clientID,
			"Cache-control": "no-cache"
		},
		success: function (data) {
			isLive = data["_total"] && data["streams"][0]["stream_type"] === "live";

			if (isLive) {
				streamer.title = data["streams"][0]["channel"]["status"];
				streamer.game = data["streams"][0]["channel"]["game"];
				streamer.viewers = data["streams"][0]["viewers"].toLocaleString();

				if (!prevStatus) {
					chrome.browserAction.setTitle({title: streamer.name + " - En Ligne"});
					chrome.browserAction.setIcon({path: "images/icon_on.png"});
					if (parseInt(localStorage.notifications) && parseInt(localStorage.lastOnline) < Date.now() - 900000) {
						createBasicNotification(streamer.name.toLowerCase() + "-live", streamer.name + " est en live !", "Je " + (streamer.game == "Talk Shows" || streamer.game == "IRL" ? "suis en " + streamer.game : "joue à " + streamer.game) + ", rejoins-moi !", "images/notif.png", [{ title: "Regarder le live", iconUrl: (streamer.liveURL.toLowerCase().indexOf("twitch.tv") >= 0 ? "js/icons/twitch.png" : "js/icons/website.png")	}]);
					}
					prevStatus = true;
					pauseCheck = 3;
				}
				
				localStorage.lastOnline = Date.now();
			} else if (prevStatus) {
				chrome.browserAction.setTitle({title: streamer.name + " - Hors-Ligne"});
				chrome.browserAction.setIcon({path: "images/icon_off.png"});
				prevStatus = false;
				pauseCheck = 3;
				streamer.title = "Hors-Ligne";
				streamer.game = "-";
				streamer.viewers = "-";

				localStorage.lastOnline = 0;
			}
		}
	});
}

function checkYoutube() {
	"use strict";

	if (streamer.youtubeId != null && parseInt(localStorage.youtube)) {
		$.ajax({
			type: "GET",
			dataType: "json",
			timeout: 20000,
			cache: false,
			url: "https://extensionsqueezie.fr/api/?playlistId=" + streamer.youtubeId,
			headers: {
				"Cache-control": "no-cache"
			},
			success: function (data) {
				if (data["publishedAt"] == -1) {
					return;
				}
				
				var publishedDate = data["publishedAt"];
				if (localStorage.lastVideo < publishedDate) {
					createImageNotification(streamer.name.toLowerCase() + "-youtube", "Vidéo de " + streamer.name + " !", data["videoTitle"], data["videoThumbnail"], "images/notif_youtube.png", "Durée : " + convertISO8601Duration(data["videoDuration"]) + " | " + parseInt(data["videoViews"]).toLocaleString() + " vues", [{ title: "Regarder la vidéo", iconUrl: "js/icons/youtube.png" }]);
					localStorage.lastVideoID = data["videoId"];
					localStorage.lastVideo = publishedDate;
				}
			}
		});
	}
}

function checkYoutube2() {
	"use strict";

	if (streamer.youtubeId2 != null && parseInt(localStorage.youtube)) {
		$.ajax({
			type: "GET",
			dataType: "json",
			timeout: 20000,
			cache: false,
			url: "https://extensionsqueezie.fr/api/?playlistId=" + streamer.youtubeId2,
			headers: {
				"Cache-control": "no-cache"
			},
			success: function (data) {
				if (data["publishedAt"] == -1) {
					return;
				}
				
				var publishedDate = data["publishedAt"];
				if (localStorage.lastVideo < publishedDate) {
					createImageNotification(streamer.name.toLowerCase() + "-youtube", "Vidéo de " + streamer.name + " !", data["videoTitle"], data["videoThumbnail"], "images/notif_youtube.png", "Durée : " + convertISO8601Duration(data["videoDuration"]) + " | " + parseInt(data["videoViews"]).toLocaleString() + " vues", [{ title: "Regarder la vidéo", iconUrl: "js/icons/youtube.png" }]);
					localStorage.lastVideoID = data["videoId"];
					localStorage.lastVideo = publishedDate;
				}
			}
		});
	}
}

if ($.browser.chrome && !$.browser.opera) {
	chrome.notifications.onButtonClicked.addListener(function(e, b) {
		if (e == streamer.name.toLowerCase() + "-options") {
			chrome.runtime.openOptionsPage();
		} else if (e == streamer.name.toLowerCase() + "-youtube") {
			chrome.tabs.create({
				url: "https://youtu.be/" + localStorage.lastVideoID
			});
		} else if (e == streamer.name.toLowerCase() + "-live") {
			chrome.tabs.create({
				url: streamer.liveURL
			});
		}

		chrome.notifications.clear(e);
	});
}

chrome.notifications.onClicked.addListener(function(e) {
	if (e == streamer.name.toLowerCase() + "-options") {
		chrome.runtime.openOptionsPage();
	} else if (e == streamer.name.toLowerCase() + "-youtube") {
		chrome.tabs.create({
			url: "https://youtu.be/" + localStorage.lastVideoID
		});
	} else if (e == streamer.name.toLowerCase() + "-live") {
		chrome.tabs.create({
			url: streamer.liveURL
		});
	}

	chrome.notifications.clear(e);
});

chrome.browserAction.setIcon({
	path: "images/icon_off.png"
});

setTimeout(function () {
	if (typeof localStorage.firstTime === 'undefined' || localStorage.firstTime === null) {
		localStorage.firstTime = true;
		createBasicNotification(streamer.name.toLowerCase() + "-options", "Merci de m'avoir installée !", "Tu peux maintenant pleinement profiter de tous les avantages de mon extension !", "images/notif_options.png", [{title: "Accéder aux options", iconUrl: "js/icons/options.png"}]);
	}

	checkLive();
	checkYoutube();
	checkYoutube2();
}, 500);

setInterval(checkLive, 30000);
setInterval(function() { checkYoutube(); }, 300000);
setInterval(function() { checkYoutube2(); }, 300000);


/**
 *  Converts an ISO-8601 formatted string to a different timestamp format (HH:MM:SS)
 *
 *  @param {string} t The ISO-8601 formmated string
 *  @returns {string} Returns duration in HH:MM:SS format
 */
function convertISO8601Duration(t){
	var x = t.split('T'),
		duration = '',
		time = {},
		period = {},
		s = 'string',
		v = 'variables',
		l = 'letters',
		d = {
			period: {
				string: x[0].substring(1,x[0].length),
				len: 4,
				letters: ['Y', 'M', 'W', 'D'],
				variables: {}
			},
			time: {
				string: x[1],
				len: 3,
				letters: ['H', 'M', 'S'],
				variables: {}
			}
		};

	if (!d.time.string) {
		d.time.string = '';
	}

	for (var i in d) {
		var len = d[i].len;
		for (var j = 0; j < len; j++) {
			d[i][s] = d[i][s].split(d[i][l][j]);
			if (d[i][s].length>1) {
				d[i][v][d[i][l][j]] = parseInt(d[i][s][0], 10);
				d[i][s] = d[i][s][1];
			} else {
				d[i][v][d[i][l][j]] = 0;
				d[i][s] = d[i][s][0];
			}
		}
	}
	period = d.period.variables;
	time = d.time.variables;
	time.H +=   24 * period.D +
				24 * 7 * period.W +
				24 * 7 * 4 * period.M +
				24 * 7 * 4 * 12 * period.Y;

	if (time.H) {
		duration = time.H + ':';
		if (time.M < 10) {
			time.M = '0' + time.M;
		}
	}

	if (time.S < 10) {
		time.S = '0' + time.S;
	}

	duration += time.M + ':' + time.S;
	return duration;
}
